pub mod create_one;
pub mod create_many;
pub mod delete_one;
pub mod get_full_collection;
pub mod get_many_by_id;
pub mod get_most_recent;
pub mod get_most_recent_with_skip;
pub mod get_one;
pub mod get_some;
pub mod update_many;
pub mod update_one;
